Crate rudeboy_derive

This crate provides derive and attr macros for use by the rudeboy crate. Please refer to it for documentation and usage information.

Attribute Macros

metamethods
Placed on a struct or enum definition; generates an impl of RudeboyMetamethods to add the specified metamethods to the exported user data.
methods
Placed on an inherent impl block; generates an impl of RudeboyMethods to add the contained methods to the exported user data. Takes no parameters.
user_data
Generates an implementation of rlua::UserData for the tagged type definition or the type that matches a tagged impl block.