This crate provides derive and attr macros for use by the rudeboy crate.
Please refer to it for documentation and usage information.
Attribute Macros
- metamethods
- Placed on a struct or enum definition; generates an impl of
RudeboyMetamethodsto add the specified metamethods to the exported user data. - methods
- Placed on an inherent impl block; generates an impl of
RudeboyMethodsto add the contained methods to the exported user data. Takes no parameters. - user_
data - Generates an implementation of
rlua::UserDatafor the tagged type definition or the type that matches a tagged impl block.